@@ -10,7 +10,7 @@ from modules.scanner import AnalyseScanResults, PortScan, DiscoverHosts
 from modules.outfile import InitializeOutput, WriteToFile, OutputBanner
 
 __author__ = 'GamehunterKaan'
-__version__ = '1.0.4'
+__version__ = '1.0.5'
 
 #parse command line arguments
 argparser = ArgumentParser(description="AutoPWN Suite")
@@ -18,6 +18,7 @@ argparser.add_argument("-o", "--output", help="Output file name. (Default : auto
 argparser.add_argument("-t", "--target", help="Target range to scan. This argument overwrites the hostfile argument. (192.168.0.1 or 192.168.0.0/24)")
 argparser.add_argument("-hf", "--hostfile", help="File containing a list of hosts to scan.")
 argparser.add_argument("-st", "--scantype", help="Scan type. (Ping or ARP)")
+argparser.add_argument("-nf", "--nmapflags", help="Custom nmap flags to use for portscan. (Has to be specified like : -nf=\"-O\")", default="")
 argparser.add_argument("-s", "--speed", help="Scan speed. (0-5) (Default : 3)", default=3)
 argparser.add_argument("-a", "--api", help="Specify API key for vulnerability detection for faster scanning. You can also specify your API key in api.txt file. (Default : None)", default=None)
 argparser.add_argument("-y", "--yesplease", help="Don't ask for anything. (Full automatic mode)",action="store_true")
@@ -48,7 +49,7 @@ if args.scantype == "arp":
         scantype = "ping"
 elif args.scantype == "ping":
     pass
-elif args.scantype == "":
+elif args.scantype == "" or type(args.scantype) == None or args.scantype == None:
     if is_root():
         scantype = "arp"
     else:
@@ -61,6 +62,7 @@ else:
         scantype = "ping"
         print_colored("Unknown scan type: %s! Using ping scan instead..." % (args.scantype), colors.red)
 
+nmapflags = args.nmapflags
 scanspeed = int(args.speed)
 
 if is_root() == False:
@@ -203,21 +205,48 @@ def UserWantsVulnerabilityDetection():
 
 #post scan stuff
 def FurtherEnumuration(hosts):
+    if len(hosts) == 0:
+        print_colored("No hosts found!", colors.red)
+        exit(0)
+    index = 0
     for host in hosts:
-        print(host.center(60))
-        WriteToFile(host.center(60))
-    if UserWantsPortScan():
-        for host in hosts:
-            WriteToFile("\n" + "-" * 60)
-            PortScanResults = PortScan(host, scanspeed, scanmode)
-            PortArray = AnalyseScanResults(PortScanResults,host)
-            if len(PortArray) > 0:
-                if UserWantsVulnerabilityDetection():
-                    SearchSploits(PortArray, apiKey)
+        print(("%s[%s%d%s]%s %s" % (bcolors.red, bcolors.endc, index, bcolors.red, bcolors.endc, host)).center(60))
+        WriteToFile(("[%d] %s" % (index, host)).center(60))
+        index += 1
+    if not DontAskForConfirmation:
+        print_colored("\nEnter the index number of the host you would like to enumurate further.", colors.yellow)
+        print_colored("Enter 'all' to enumurate all hosts.", colors.yellow)
+        print_colored("Enter 'exit' to exit.\n", colors.yellow)
+        while True:
+            host = input(bcolors.blue + "----> " + bcolors.endc)
+            if host == 'all':
+                Targets = hosts
+                break
+            elif host == 'exit':
+                exit(0)
+            elif host in hosts:
+                Targets = [host]
+                break
+            elif int(host) < len(hosts) and int(host) >= 0:
+                Targets = [hosts[int(host)]]
+                break
             else:
-                print("Skipping vulnerability detection for " + str(host))
-                WriteToFile("Skipped vulnerability detection for " + str(host))
-            WriteToFile("\n" + "-" * 60)
+                print_colored("Please enter a valid host number or 'all' or 'exit'", colors.red)
+    else:
+        Targets = hosts
+    if UserWantsPortScan():
+        if UserWantsVulnerabilityDetection():
+            for host in Targets:
+                PortScanResults = PortScan(host, scanspeed, scanmode, nmapflags)
+                PortArray = AnalyseScanResults(PortScanResults,host)
+                if len(PortArray) > 0:
+                    SearchSploits(PortArray, apiKey)
+        else:
+            for host in Targets:
+                PortScanResults = PortScan(host, scanspeed, scanmode, nmapflags)
+                PortArray = AnalyseScanResults(PortScanResults,host)
+    else:
+        exit(0)
 
 #main function
 def main():
