@@ -28,7 +28,7 @@ def listToString(s):
     return (str1.join(s))
 
 #do a ping scan using nmap
-def TestPing(target, mode):
+def TestPing(target, mode="normal"):
     nm = PortScanner()
     if type(target) is list:
         target = listToString(target)
@@ -39,7 +39,7 @@ def TestPing(target, mode):
     return nm.all_hosts()
 
 #do a arp scan using nmap
-def TestArp(target, mode):
+def TestArp(target, mode="normal"):
     nm = PortScanner()
     if type(target) is list:
         target = listToString(target)
@@ -50,19 +50,30 @@ def TestArp(target, mode):
     return nm.all_hosts()
 
 #run a port scan on target using nmap
-def PortScan(target, scanspeed, mode):
+def PortScan(target, scanspeed=5, mode="normal", customflags=""):
     print_colored("\n" + "-" * 60, colors.green)
     print_colored(("Running a portscan on host " + str(target) + "...").center(60), colors.green)
     print_colored("-" * 60 + "\n", colors.green)
-    WriteToFile("\nPortscan on " + str(target) + " : ")
+
+    WriteToFile("\n" + "-" * 60)
+    WriteToFile(("Portscan results for host " + str(target) + ".").center(60))
+    WriteToFile("-" * 60 + "\n")
+
     nm = PortScanner()
-    if is_root():
-        if mode == "evade":
-            resp = nm.scan(hosts=target, arguments="-sS -sV -O -Pn -T 2 -f -g 53 --data-length 10")
+
+    try:
+        if is_root():
+            if mode == "evade":
+                resp = nm.scan(hosts=target, arguments="-sS -sV -O -Pn -T 2 -f -g 53 --data-length 10 %s" % (customflags))
+            else:
+                resp = nm.scan(hosts=target, arguments="-sS -sV --host-timeout 60 -Pn -O -T %d %s" % (scanspeed, customflags))
         else:
-            resp = nm.scan(hosts=target, arguments="-sS -sV --host-timeout 60 -Pn -O -T %d" % (scanspeed))
-    else:
-        resp = nm.scan(hosts=target, arguments="-sV --host-timeout 60 -Pn -T %d" % (scanspeed))
+            resp = nm.scan(hosts=target, arguments="-sV --host-timeout 60 -Pn -T %d %s" % (scanspeed, customflags))
+    except Exception as e:
+        print_colored("Error: %s" % (e), colors.red)
+        WriteToFile("Error: %s" % (e))
+        exit(0)
+
     return nm
 
 def CreateNoise(target):
@@ -77,7 +88,7 @@ def CreateNoise(target):
     except KeyboardInterrupt:
         pass
 
-def DiscoverHosts(target, scantype, scanspeed, mode):
+def DiscoverHosts(target, scantype="arp", scanspeed=3, mode="normal", customflags=""):
     if mode == "noise":
         print_colored("\n" + "-" * 60, colors.green)
         print_colored("Creating noise...".center(60), colors.green)
@@ -103,15 +114,17 @@ def DiscoverHosts(target, scantype, scanspeed, mode):
                 exit(0)
     else:
         print_colored("\n" + "-" * 60, colors.green)
+        WriteToFile("\n" + "-" * 60)
         if type(target) is list:
             print_colored(("Scanning " + str(len(target)) + " target(s) using " + scantype + " scan...").center(60), colors.green)
             WriteToFile("\nScanning %d hosts using %s scan..." % (len(target), scantype))
         else:
             print_colored(("Scanning " + target + " using " + scantype + " scan...").center(60), colors.green)
-            WriteToFile("\nScanning %s using %s scan..." % (target, scantype))
+            WriteToFile(("Scanning " + target + " using " + scantype + " scan...").center(60))
         
         print_colored("-" * 60 + "\n", colors.green)
-        
+        WriteToFile("-" * 60 + "\n")
+
         if scantype == "ping":
             OnlineHosts = TestPing(target, mode)
             return OnlineHosts
@@ -187,7 +200,7 @@ def AnalyseScanResults(nm,target):
 
         if nm[target]['status']['reason'] == 'localhost-response' or nm[target]['status']['reason'] == 'user-set':
             print_colored('Target ' + str(target) + ' seems to be us.', colors.underline)
-            WriteToFile('Target ' + str(target) + ' seems to be us.')
+            WriteToFile('Target ' + str(target) + ' seems to be us.\n')
         if len(nm[target].all_protocols()) == 0:
             print_colored("Target " + str(target) + " seems to have no open ports.", colors.red)
             WriteToFile("Target " + str(target) + " seems to have no open ports.")
